@@ -179,9 +179,9 @@ def test_formset_m2m_nested(request_post, request_get, db_queries):
             'fm2m': MyAnotherNestedForm,
         }
 
-    # form = MyFormWithSet(request=request_get(), src='POST')
-    # html = f'{form}'
-    # assert 'name="fm2m-0-fadd-fnum" maxlength="5" ' in html
+    form = MyFormWithSet(request=request_get(), src='POST')
+    html = f'{form}'
+    assert 'name="fm2m-0-fadd-fnum" maxlength="5" ' in html
 
     add1 = Additional.objects.create(fnum='eee')
     add2 = Additional.objects.create(fnum='www')
@@ -195,11 +195,11 @@ def test_formset_m2m_nested(request_post, request_get, db_queries):
     thing = AnotherThing.objects.get(id=thing.id)
 
     # Check subform is rendered with instance data.
-    # form = MyFormWithSet(request=request_get(), src='POST', instance=thing)
-    # html = f'{form}'
-    # assert 'name="fm2m-TOTAL_FORMS"' in html
-    # assert 'name="fm2m-0-fsome" value="888" ' in html
-    # assert 'name="fm2m-0-fadd-fnum" value="eee" ' in html
+    form = MyFormWithSet(request=request_get(), src='POST', instance=thing)
+    html = f'{form}'
+    assert 'name="fm2m-TOTAL_FORMS"' in html
+    assert 'name="fm2m-0-fsome" value="888" ' in html
+    assert 'name="fm2m-0-fadd-fnum" value="eee" ' in html
 
     assert AnotherThing.objects.count() == 1
     assert Another.objects.count() == 2
@@ -480,22 +480,24 @@ def test_json_subforms(form_cls, request_get, request_post):
     assert thing.ftext == 'two'
 
 
+class MyAnotherNestedForm(MyAnotherForm):
+
+    readonly_fields = '__all__'
+
+    subforms = {
+        'fadd': MyAdditionalForm,
+    }
+
+
+class MyFormWithSet(MyAnotherThingForm):
+
+    subforms = {
+        'fm2m': MyAnotherNestedForm,
+    }
+
+
 def test_no_basefields_sideeffect(request_get):
 
-    class MyAnotherNestedForm(MyAnotherForm):
-
-        readonly_fields = '__all__'
-
-        subforms = {
-            'fadd': MyAdditionalForm,
-        }
-
-    class MyFormWithSet(MyAnotherThingForm):
-
-        subforms = {
-            'fm2m': MyAnotherNestedForm,
-        }
-
     add1 = Additional.objects.create(fnum='eee')
     another1 = Another.objects.create(fsome='888', fadd=add1)
 
@@ -511,3 +513,33 @@ def test_no_basefields_sideeffect(request_get):
     html = f'{form}'
     assert '" required id="id_fsome"' in html
     assert 'disabled' not in html
+
+
+def test_cheap_details_view(request_get):
+
+    add1 = Additional.objects.create(fnum='eee')
+    another1 = Another.objects.create(fsome='888', fadd=add1)
+    another2 = Another.objects.create(fsome='999', fadd=add1)
+
+    thing = AnotherThing.objects.create(fchar='one')
+    thing.fm2m.add(another1, another2)
+
+    form = MyFormWithSet(
+        request=request_get(), src='POST', instance=thing,
+        readonly_fields='__all__', render_form_tag=False)
+
+    html = f'{form}'
+    assert 'disabled>999</div>' in html
+    assert '<form ' not in html
+
+
+def test_render_form_tag(form_cls, request_get):
+
+    def spawn(**kwargs):
+        return form_cls(model=Thing, use_fields=['fchar', 'ftext'])(**kwargs)
+
+    form = spawn()
+    assert '<form ' in f'{form}'
+
+    form = spawn(render_form_tag=False)
+    assert '<form ' not in f'{form}'
